summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2006-12-25 13:29:43 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-09-03 12:23:54 -0500
commit295e9df783be10115dbe20ff2c578ca92e742c31 (patch)
treeb07493ffe56376f8b281fd4385ba3afb4b4a0472 /png.h
parentef860dab8f5e8f8ffa7f958a40fa12226de8cc45 (diff)
downloadlibpng-295e9df783be10115dbe20ff2c578ca92e742c31.tar.gz
[libpng10] Imported from libpng-1.0.23rc3.tarv1.0.23rc3
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index 030c9bf68..4ccda2a3c 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.0.23rc2 - December 21, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.0.23rc2 - December 21, 2006: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -166,7 +166,7 @@
* If you modify libpng you may insert additional notices immediately following
* this sentence.
*
* libpng versions 1.2.6, August 15, 2004, through 1.0.23rc2, December 21, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -278,13 +278,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 21, 2006
+ * December 25, 2006
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.0.23rc2 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -340,9 +340,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.0.23rc2"
+#define PNG_LIBPNG_VER_STRING "1.0.23rc3"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.0.23rc2 - December 21, 2006 (header)\n"
+ " libpng version 1.0.23rc3 - December 25, 2006 (header)\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 10
@@ -354,7 +354,7 @@
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero: */
-#define PNG_LIBPNG_VER_BUILD 2
+#define PNG_LIBPNG_VER_BUILD 3
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1388,7 +1388,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_0_23rc2;
+typedef png_structp version_1_0_23rc3;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.0.23rc2 - December 21, 2006
+ * libpng version 1.0.23rc3 - December 25, 2006
* Copyright (c) 1998-2006 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.0.23rc2 - December 21, 2006: Glenn
+ * libpng versions 0.97, January 1998, through 1.0.23rc3 - December 25, 2006: Glenn
* See also "Contributing Authors", below.
*
@@ -166,7 +166,7 @@
* this sentence.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.0.23rc2, December 21, 2006, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.0.23rc3, December 25, 2006, are
* Copyright (c) 2004, 2006 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -278,13 +278,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.0.23rc2 are Y2K compliant. It is my belief that earlier
+ * upward through 1.0.23rc3 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*